# `solar_apparent_time` Python Package

The `solar_apparent_time` Python package translates Python datetime between solar apparent time and Coordinate Universal Time (UTC).

[Gregory H. Halverson](https://github.com/gregory-halverson-jpl) (they/them)<br>
[gregory.h.halverson@jpl.nasa.gov](mailto:gregory.h.halverson@jpl.nasa.gov)<br>
NASA Jet Propulsion Laboratory 329G
